Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(98)

Unified Diff: ios/chrome/browser/ui/content_suggestions/content_suggestions_article_item.h

Issue 2697573002: Modify article item in ContentSuggestions (Closed)
Patch Set: Fix tests Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/ui/content_suggestions/content_suggestions_article_item.h
diff --git a/ios/chrome/browser/ui/content_suggestions/content_suggestions_article_item.h b/ios/chrome/browser/ui/content_suggestions/content_suggestions_article_item.h
index 7415da2197132e8bf7c67b451b02da6317ba4890..0c1a4b96ef465b54d16ec61a728a8a4513beb81a 100644
--- a/ios/chrome/browser/ui/content_suggestions/content_suggestions_article_item.h
+++ b/ios/chrome/browser/ui/content_suggestions/content_suggestions_article_item.h
@@ -7,19 +7,24 @@
#import "ios/chrome/browser/ui/collection_view/cells/collection_view_item.h"
#import "ios/third_party/material_components_ios/src/components/CollectionCells/src/MaterialCollectionCells.h"
+#include "url/gurl.h"
// Item for an article in the suggestions.
@interface ContentSuggestionsArticleItem : CollectionViewItem
-// Initialize an article with a |title|, a |subtitle| and an |image|. |type| is
-// the type of the item.
+// Initialize an article with a |title|, a |subtitle|, an |image| and the |url|
+// to the full article. |type| is the type of the item.
- (instancetype)initWithType:(NSInteger)type
title:(NSString*)title
subtitle:(NSString*)subtitle
- image:(UIImage*)image NS_DESIGNATED_INITIALIZER;
+ image:(UIImage*)image
+ url:(const GURL&)url NS_DESIGNATED_INITIALIZER;
- (instancetype)initWithType:(NSInteger)type NS_UNAVAILABLE;
+@property(nonatomic, strong) UIImage* image;
+@property(nonatomic, readonly, assign) GURL articleURL;
+
@end
// Corresponding cell for an article in the suggestions.

Powered by Google App Engine
This is Rietveld 408576698